pub enum Error {
Io(Error),
TruncatedFrame,
ChecksumMismatch,
DecompressionFailed,
}Variants
Io(Error)
Underlying IO error.
TruncatedFrame
Header or payload truncated at the tail of the segment.
ChecksumMismatch
Block trailer’s checksum did not match the payload’s checksum.
Raised by the crc32 and xxh3 opt-in readers.
DecompressionFailed
Block’s algorithm tag is unknown or a decompress call failed.
Raised by the lz4 opt-in reader.